==> devops-client-java-1.0.2-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineTemplateTaskFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.util.Map;

public interface V1alpha1PipelineTemplateTaskFluent<A extends V1alpha1PipelineTemplateTaskFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAgent instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1JenkinsAgent getAgent();
    public V1alpha1JenkinsAgent buildAgent();
    public A withAgent(V1alpha1JenkinsAgent agent);
    public Boolean hasAgent();
    public V1alpha1PipelineTemplateTaskFluent.AgentNested<A> withNewAgent();
    public V1alpha1PipelineTemplateTaskFluent.AgentNested<A> withNewAgentLike(V1alpha1JenkinsAgent item);
    public V1alpha1PipelineTemplateTaskFluent.AgentNested<A> editAgent();
    public V1alpha1PipelineTemplateTaskFluent.AgentNested<A> editOrNewAgent();
    public V1alpha1PipelineTemplateTaskFluent.AgentNested<A> editOrNewAgentLike(V1alpha1JenkinsAgent item);
    
/**
 * This method has been deprecated, please use method buildApprove instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineTaskApprove getApprove();
    public V1alpha1PipelineTaskApprove buildApprove();
    public A withApprove(V1alpha1PipelineTaskApprove approve);
    public Boolean hasApprove();
    public V1alpha1PipelineTemplateTaskFluent.ApproveNested<A> withNewApprove();
    public V1alpha1PipelineTemplateTaskFluent.ApproveNested<A> withNewApproveLike(V1alpha1PipelineTaskApprove item);
    public V1alpha1PipelineTemplateTaskFluent.ApproveNested<A> editApprove();
    public V1alpha1PipelineTemplateTaskFluent.ApproveNested<A> editOrNewApprove();
    public V1alpha1PipelineTemplateTaskFluent.ApproveNested<A> editOrNewApproveLike(V1alpha1PipelineTaskApprove item);
    public A addToConditions(String key,List<String> value);
    public A addToConditions(Map<String,List<String>> map);
    public A removeFromConditions(String key);
    public A removeFromConditions(Map<String,List<String>> map);
    public Map<String,List<String>> getConditions();
    public A withConditions(Map<String,List<String>> conditions);
    public Boolean hasConditions();
    
/**
 * This method has been deprecated, please use method buildDisplay instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1I18nName getDisplay();
    public V1alpha1I18nName buildDisplay();
    public A withDisplay(V1alpha1I18nName display);
    public Boolean hasDisplay();
    public V1alpha1PipelineTemplateTaskFluent.DisplayNested<A> withNewDisplay();
    public V1alpha1PipelineTemplateTaskFluent.DisplayNested<A> withNewDisplayLike(V1alpha1I18nName item);
    public V1alpha1PipelineTemplateTaskFluent.DisplayNested<A> editDisplay();
    public V1alpha1PipelineTemplateTaskFluent.DisplayNested<A> editOrNewDisplay();
    public V1alpha1PipelineTemplateTaskFluent.DisplayNested<A> editOrNewDisplayLike(V1alpha1I18nName item);
    public A addToEnvironments(int index,V1alpha1PipelineEnvironment item);
    public A setToEnvironments(int index,V1alpha1PipelineEnvironment item);
    public A addToEnvironments(V1alpha1PipelineEnvironment... items);
    public A addAllToEnvironments(Collection<V1alpha1PipelineEnvironment> items);
    public A removeFromEnvironments(V1alpha1PipelineEnvironment... items);
    public A removeAllFromEnvironments(Collection<V1alpha1PipelineEnvironment> items);
    
/**
 * This method has been deprecated, please use method buildEnvironments instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineEnvironment> getEnvironments();
    public List<V1alpha1PipelineEnvironment> buildEnvironments();
    public V1alpha1PipelineEnvironment buildEnvironment(int index);
    public V1alpha1PipelineEnvironment buildFirstEnvironment();
    public V1alpha1PipelineEnvironment buildLastEnvironment();
    public V1alpha1PipelineEnvironment buildMatchingEnvironment(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineEnvironmentBuilder> predicate);
    public Boolean hasMatchingEnvironment(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineEnvironmentBuilder> predicate);
    public A withEnvironments(List<V1alpha1PipelineEnvironment> environments);
    public A withEnvironments(V1alpha1PipelineEnvironment... environments);
    public Boolean hasEnvironments();
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> addNewEnvironment();
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> addNewEnvironmentLike(V1alpha1PipelineEnvironment item);
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> setNewEnvironmentLike(int index,V1alpha1PipelineEnvironment item);
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> editEnvironment(int index);
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> editFirstEnvironment();
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> editLastEnvironment();
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> editMatchingEnvironment(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineEnvironmentBuilder> predicate);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildOptions instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineTaskOption getOptions();
    public V1alpha1PipelineTaskOption buildOptions();
    public A withOptions(V1alpha1PipelineTaskOption options);
    public Boolean hasOptions();
    public V1alpha1PipelineTemplateTaskFluent.OptionsNested<A> withNewOptions();
    public V1alpha1PipelineTemplateTaskFluent.OptionsNested<A> withNewOptionsLike(V1alpha1PipelineTaskOption item);
    public V1alpha1PipelineTemplateTaskFluent.OptionsNested<A> editOptions();
    public V1alpha1PipelineTemplateTaskFluent.OptionsNested<A> editOrNewOptions();
    public V1alpha1PipelineTemplateTaskFluent.OptionsNested<A> editOrNewOptionsLike(V1alpha1PipelineTaskOption item);
    public A addToRelation(int index,V1alpha1PipelineTaskArgumentAction item);
    public A setToRelation(int index,V1alpha1PipelineTaskArgumentAction item);
    public A addToRelation(V1alpha1PipelineTaskArgumentAction... items);
    public A addAllToRelation(Collection<V1alpha1PipelineTaskArgumentAction> items);
    public A removeFromRelation(V1alpha1PipelineTaskArgumentAction... items);
    public A removeAllFromRelation(Collection<V1alpha1PipelineTaskArgumentAction> items);
    
/**
 * This method has been deprecated, please use method buildRelation instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineTaskArgumentAction> getRelation();
    public List<V1alpha1PipelineTaskArgumentAction> buildRelation();
    public V1alpha1PipelineTaskArgumentAction buildRelation(int index);
    public V1alpha1PipelineTaskArgumentAction buildFirstRelation();
    public V1alpha1PipelineTaskArgumentAction buildLastRelation();
    public V1alpha1PipelineTaskArgumentAction buildMatchingRelation(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentActionBuilder> predicate);
    public Boolean hasMatchingRelation(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentActionBuilder> predicate);
    public A withRelation(List<V1alpha1PipelineTaskArgumentAction> relation);
    public A withRelation(V1alpha1PipelineTaskArgumentAction... relation);
    public Boolean hasRelation();
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> addNewRelation();
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> addNewRelationLike(V1alpha1PipelineTaskArgumentAction item);
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> setNewRelationLike(int index,V1alpha1PipelineTaskArgumentAction item);
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> editRelation(int index);
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> editFirstRelation();
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> editLastRelation();
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> editMatchingRelation(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentActionBuilder> predicate);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface AgentNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1JenkinsAgentFluent<V1alpha1PipelineTemplateTaskFluent.AgentNested<N>>{

        
    public N and();    public N endAgent();
}
    public interface ApproveNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTaskApproveFluent<V1alpha1PipelineTemplateTaskFluent.ApproveNested<N>>{

        
    public N and();    public N endApprove();
}
    public interface DisplayNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1I18nNameFluent<V1alpha1PipelineTemplateTaskFluent.DisplayNested<N>>{

        
    public N and();    public N endDisplay();
}
    public interface EnvironmentsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineEnvironmentFluent<V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<N>>{

        
    public N and();    public N endEnvironment();
}
    public interface OptionsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTaskOptionFluent<V1alpha1PipelineTemplateTaskFluent.OptionsNested<N>>{

        
    public N and();    public N endOptions();
}
    public interface RelationNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTaskArgumentActionFluent<V1alpha1PipelineTemplateTaskFluent.RelationNested<N>>{

        
    public N and();    public N endRelation();
}


}

==> devops-client-java-1.0.6-sources.jar: io/alauda/devops/java/client/models/V1alpha1PipelineTemplateTaskFluent.java <==
package io.alauda.devops.java.client.models;

import java.lang.StringBuilder;
import com.google.gson.annotations.SerializedName;
import io.alauda.devops.java.client.fluent.Nested;
import java.util.ArrayList;
import java.lang.String;
import io.alauda.devops.java.client.fluent.Predicate;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.util.List;
import java.lang.Boolean;
import io.alauda.devops.java.client.fluent.Fluent;
import java.lang.StringBuffer;
import java.util.Collection;
import java.util.Map;

public interface V1alpha1PipelineTemplateTaskFluent<A extends V1alpha1PipelineTemplateTaskFluent<A>> extends Fluent<A>{


    
/**
 * This method has been deprecated, please use method buildAgent instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1JenkinsAgent getAgent();
    public V1alpha1JenkinsAgent buildAgent();
    public A withAgent(V1alpha1JenkinsAgent agent);
    public Boolean hasAgent();
    public V1alpha1PipelineTemplateTaskFluent.AgentNested<A> withNewAgent();
    public V1alpha1PipelineTemplateTaskFluent.AgentNested<A> withNewAgentLike(V1alpha1JenkinsAgent item);
    public V1alpha1PipelineTemplateTaskFluent.AgentNested<A> editAgent();
    public V1alpha1PipelineTemplateTaskFluent.AgentNested<A> editOrNewAgent();
    public V1alpha1PipelineTemplateTaskFluent.AgentNested<A> editOrNewAgentLike(V1alpha1JenkinsAgent item);
    
/**
 * This method has been deprecated, please use method buildApprove instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineTaskApprove getApprove();
    public V1alpha1PipelineTaskApprove buildApprove();
    public A withApprove(V1alpha1PipelineTaskApprove approve);
    public Boolean hasApprove();
    public V1alpha1PipelineTemplateTaskFluent.ApproveNested<A> withNewApprove();
    public V1alpha1PipelineTemplateTaskFluent.ApproveNested<A> withNewApproveLike(V1alpha1PipelineTaskApprove item);
    public V1alpha1PipelineTemplateTaskFluent.ApproveNested<A> editApprove();
    public V1alpha1PipelineTemplateTaskFluent.ApproveNested<A> editOrNewApprove();
    public V1alpha1PipelineTemplateTaskFluent.ApproveNested<A> editOrNewApproveLike(V1alpha1PipelineTaskApprove item);
    public A addToConditions(String key,List<String> value);
    public A addToConditions(Map<String,List<String>> map);
    public A removeFromConditions(String key);
    public A removeFromConditions(Map<String,List<String>> map);
    public Map<String,List<String>> getConditions();
    public A withConditions(Map<String,List<String>> conditions);
    public Boolean hasConditions();
    
/**
 * This method has been deprecated, please use method buildDisplay instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1I18nName getDisplay();
    public V1alpha1I18nName buildDisplay();
    public A withDisplay(V1alpha1I18nName display);
    public Boolean hasDisplay();
    public V1alpha1PipelineTemplateTaskFluent.DisplayNested<A> withNewDisplay();
    public V1alpha1PipelineTemplateTaskFluent.DisplayNested<A> withNewDisplayLike(V1alpha1I18nName item);
    public V1alpha1PipelineTemplateTaskFluent.DisplayNested<A> editDisplay();
    public V1alpha1PipelineTemplateTaskFluent.DisplayNested<A> editOrNewDisplay();
    public V1alpha1PipelineTemplateTaskFluent.DisplayNested<A> editOrNewDisplayLike(V1alpha1I18nName item);
    public A addToEnvironments(int index,V1alpha1PipelineEnvironment item);
    public A setToEnvironments(int index,V1alpha1PipelineEnvironment item);
    public A addToEnvironments(V1alpha1PipelineEnvironment... items);
    public A addAllToEnvironments(Collection<V1alpha1PipelineEnvironment> items);
    public A removeFromEnvironments(V1alpha1PipelineEnvironment... items);
    public A removeAllFromEnvironments(Collection<V1alpha1PipelineEnvironment> items);
    
/**
 * This method has been deprecated, please use method buildEnvironments instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineEnvironment> getEnvironments();
    public List<V1alpha1PipelineEnvironment> buildEnvironments();
    public V1alpha1PipelineEnvironment buildEnvironment(int index);
    public V1alpha1PipelineEnvironment buildFirstEnvironment();
    public V1alpha1PipelineEnvironment buildLastEnvironment();
    public V1alpha1PipelineEnvironment buildMatchingEnvironment(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineEnvironmentBuilder> predicate);
    public Boolean hasMatchingEnvironment(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineEnvironmentBuilder> predicate);
    public A withEnvironments(List<V1alpha1PipelineEnvironment> environments);
    public A withEnvironments(V1alpha1PipelineEnvironment... environments);
    public Boolean hasEnvironments();
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> addNewEnvironment();
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> addNewEnvironmentLike(V1alpha1PipelineEnvironment item);
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> setNewEnvironmentLike(int index,V1alpha1PipelineEnvironment item);
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> editEnvironment(int index);
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> editFirstEnvironment();
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> editLastEnvironment();
    public V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<A> editMatchingEnvironment(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineEnvironmentBuilder> predicate);
    public String getId();
    public A withId(String id);
    public Boolean hasId();
    public A withNewId(String arg1);
    public A withNewId(StringBuilder arg1);
    public A withNewId(StringBuffer arg1);
    public String getKind();
    public A withKind(String kind);
    public Boolean hasKind();
    public A withNewKind(String arg1);
    public A withNewKind(StringBuilder arg1);
    public A withNewKind(StringBuffer arg1);
    public String getName();
    public A withName(String name);
    public Boolean hasName();
    public A withNewName(String arg1);
    public A withNewName(StringBuilder arg1);
    public A withNewName(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildOptions instead.
 * @return The buildable object.
 */
@Deprecated public V1alpha1PipelineTaskOption getOptions();
    public V1alpha1PipelineTaskOption buildOptions();
    public A withOptions(V1alpha1PipelineTaskOption options);
    public Boolean hasOptions();
    public V1alpha1PipelineTemplateTaskFluent.OptionsNested<A> withNewOptions();
    public V1alpha1PipelineTemplateTaskFluent.OptionsNested<A> withNewOptionsLike(V1alpha1PipelineTaskOption item);
    public V1alpha1PipelineTemplateTaskFluent.OptionsNested<A> editOptions();
    public V1alpha1PipelineTemplateTaskFluent.OptionsNested<A> editOrNewOptions();
    public V1alpha1PipelineTemplateTaskFluent.OptionsNested<A> editOrNewOptionsLike(V1alpha1PipelineTaskOption item);
    public A addToRelation(int index,V1alpha1PipelineTaskArgumentAction item);
    public A setToRelation(int index,V1alpha1PipelineTaskArgumentAction item);
    public A addToRelation(V1alpha1PipelineTaskArgumentAction... items);
    public A addAllToRelation(Collection<V1alpha1PipelineTaskArgumentAction> items);
    public A removeFromRelation(V1alpha1PipelineTaskArgumentAction... items);
    public A removeAllFromRelation(Collection<V1alpha1PipelineTaskArgumentAction> items);
    
/**
 * This method has been deprecated, please use method buildRelation instead.
 * @return The buildable object.
 */
@Deprecated public List<V1alpha1PipelineTaskArgumentAction> getRelation();
    public List<V1alpha1PipelineTaskArgumentAction> buildRelation();
    public V1alpha1PipelineTaskArgumentAction buildRelation(int index);
    public V1alpha1PipelineTaskArgumentAction buildFirstRelation();
    public V1alpha1PipelineTaskArgumentAction buildLastRelation();
    public V1alpha1PipelineTaskArgumentAction buildMatchingRelation(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentActionBuilder> predicate);
    public Boolean hasMatchingRelation(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentActionBuilder> predicate);
    public A withRelation(List<V1alpha1PipelineTaskArgumentAction> relation);
    public A withRelation(V1alpha1PipelineTaskArgumentAction... relation);
    public Boolean hasRelation();
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> addNewRelation();
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> addNewRelationLike(V1alpha1PipelineTaskArgumentAction item);
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> setNewRelationLike(int index,V1alpha1PipelineTaskArgumentAction item);
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> editRelation(int index);
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> editFirstRelation();
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> editLastRelation();
    public V1alpha1PipelineTemplateTaskFluent.RelationNested<A> editMatchingRelation(io.alauda.devops.java.client.fluent.Predicate<V1alpha1PipelineTaskArgumentActionBuilder> predicate);
    public String getType();
    public A withType(String type);
    public Boolean hasType();
    public A withNewType(String arg1);
    public A withNewType(StringBuilder arg1);
    public A withNewType(StringBuffer arg1);

    public interface AgentNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1JenkinsAgentFluent<V1alpha1PipelineTemplateTaskFluent.AgentNested<N>>{

        
    public N and();    public N endAgent();
}
    public interface ApproveNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTaskApproveFluent<V1alpha1PipelineTemplateTaskFluent.ApproveNested<N>>{

        
    public N and();    public N endApprove();
}
    public interface DisplayNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1I18nNameFluent<V1alpha1PipelineTemplateTaskFluent.DisplayNested<N>>{

        
    public N and();    public N endDisplay();
}
    public interface EnvironmentsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineEnvironmentFluent<V1alpha1PipelineTemplateTaskFluent.EnvironmentsNested<N>>{

        
    public N and();    public N endEnvironment();
}
    public interface OptionsNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTaskOptionFluent<V1alpha1PipelineTemplateTaskFluent.OptionsNested<N>>{

        
    public N and();    public N endOptions();
}
    public interface RelationNested<N> extends io.alauda.devops.java.client.fluent.Nested<N>,V1alpha1PipelineTaskArgumentActionFluent<V1alpha1PipelineTemplateTaskFluent.RelationNested<N>>{

        
    public N and();    public N endRelation();
}


}
